@@ -166,7 +166,9 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_SIGNAL(NV_CTRL_TV_SATURATION);
     MAKE_SIGNAL(NV_CTRL_TV_RESET_SETTINGS);
     MAKE_SIGNAL(NV_CTRL_GPU_CORE_TEMPERATURE);
-    MAKE_SIGNAL(NV_CTRL_GPU_CORE_THRESHOLD);
+    MAKE_SIGNAL(NV_CTRL_GPU_SLOWDOWN_THRESHOLD);
+    MAKE_SIGNAL(NV_CTRL_GPU_SHUTDOWN_THRESHOLD);
+    MAKE_SIGNAL(NV_CTRL_GPU_MAX_OPERATING_THRESHOLD);
     MAKE_SIGNAL(NV_CTRL_GPU_DEFAULT_CORE_THRESHOLD);
     MAKE_SIGNAL(NV_CTRL_GPU_MAX_CORE_THRESHOLD);
     MAKE_SIGNAL(NV_CTRL_AMBIENT_TEMPERATURE);
@@ -360,7 +362,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
      * knows about.
      */
 
-#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_DISPLAY_VRR_ENABLED
+#if NV_CTRL_LAST_ATTRIBUTE != NV_CTRL_GPU_MAX_OPERATING_THRESHOLD
 #warning "There are attributes that do not emit signals!"
 #endif
 
@@ -417,7 +419,7 @@ static void ctk_event_class_init(CtkEventClass *ctk_event_class)
     MAKE_STRING_SIGNAL(NV_CTRL_STRING_PRIME_OUTPUTS_DATA);
 #undef MAKE_STRING_SIGNAL
 
-#if NV_CTRL_STRING_LAST_ATTRIBUTE != NV_CTRL_STRING_PRIME_OUTPUTS_DATA
+#if NV_CTRL_STRING_LAST_ATTRIBUTE != NV_CTRL_STRING_DISPLAY_NAME_CONNECTOR
 #warning "There are attributes that do not emit signals!"
 #endif
 
